@@ -33,22 +33,24 @@ eovcheck.formula = function(object, data = NULL, xlab = NULL, col = NULL,
     # we have to assume the response is continous and not a factor
 
     num.factors = sum(sapply(m, is.factor))
-    num.cts = ncol(m)-num.factors-1
+    num.cts = ncol(m) - num.factors - 1
 
     bOneWay = FALSE
     bTwoWay = FALSE
     bRegression =FALSE
     bInsuffRep = FALSE
+    p.value = NA
 
-    if(num.cts == 0 & num.factors>0){ # we're in the ANOVA realm
-        if(num.factors>2){
-            stop("This function only works for up to two factors")
+    if(num.cts == 0 & num.factors > 0){ # we're in the ANOVA realm
+        if(levene & num.factors > 2){
+            warning("This version Levene's test only works for up to two factors")
+            p.value = NA
         }else{
-            bOneWay = num.factors == 1
-            bTwoWay = num.factors == 2
+          bOneWay = num.factors == 1
+          bTwoWay = num.factors == 2
         }
     }else{
-        if(ncol(m)==1){
+        if(ncol(m) == 1){
             stop("You must have at least two variables for this function to work")
         }else{
             bRegression = TRUE
@@ -57,14 +59,16 @@ eovcheck.formula = function(object, data = NULL, xlab = NULL, col = NULL,
 
     fit = NULL
 
-    if(bOneWay | bTwoWay){
+    if(levene && (bOneWay | bTwoWay)){
 
         ## 2. There are no more than two explantory variables
 
-        factors.form = attr(terms.form,"factors")
-        num.factors = sum(apply(factors.form,1,sum)>0)
-        if(num.factors<1 || num.factors>2){
-            if(num.factors<1){
+        factors.form = attr(terms.form, "factors")
+        num.factors = sum(apply(factors.form, 1, sum) > 0)
+        
+        ## This should never get called - but just in case at this point
+        if(num.factors < 1 || num.factors > 2){
+            if(num.factors < 1){
                 stop("There must be at least one explantory variable")
             }else{
                 stop("This function only works for up to two factors")
@@ -72,7 +76,7 @@ eovcheck.formula = function(object, data = NULL, xlab = NULL, col = NULL,
         }
 
         bInteraction = FALSE
-        if(num.factors==2)
+        if(num.factors == 2)
             if(any(grep(":",attr(terms.form,"term.labels"))))
                 nIteraction = TRUE
 
@@ -90,12 +94,12 @@ eovcheck.formula = function(object, data = NULL, xlab = NULL, col = NULL,
 
         fit = lm(x~fac1)
 
-        num.obs.per.group.min = min(sapply(split(x,fac1),length))
+        num.obs.per.group.min = min(sapply(split(x, fac1), length))
         p.value = 0
 
-        if(num.obs.per.group.min==1){
+        if(num.obs.per.group.min == 1){
             stop("There is a group with no replication")
-        }else if(num.obs.per.group.min==2){
+        }else if(num.obs.per.group.min == 2){
             warning("Smallest group size is 2.\n It may make no sense to check for equality of variance")
             bInsuffRep = TRUE
         }else{
@@ -105,14 +109,15 @@ eovcheck.formula = function(object, data = NULL, xlab = NULL, col = NULL,
         fit = lm(form, data = data.f)
     }
 
-    opar = par(mfrow = c(1,1),xaxs = "r", yaxs = "r")
+    opar = par(mfrow = c(1,1), xaxs = "r", yaxs = "r")
 
-    plot(fit,sub = "",which = 1, add.smooth = FALSE)
+    plot(fit, sub = "",which = 1, add.smooth = FALSE)
     resids = residuals(fit)
     yhat = fitted(fit)
 
-    if(smoother)
-        lines(lowess(yhat,resids),col = "lightblue")
+    if(smoother){
+        lines(lowess(yhat, resids), col = "lightblue")
+    }
 
     if(twosd){
         sigma = summary(fit)$sigma
@@ -122,7 +127,7 @@ eovcheck.formula = function(object, data = NULL, xlab = NULL, col = NULL,
     xlims = usr.coords[1:2]
     ylims = usr.coords[3:4]
 
-    if((bOneWay | bTwoWay) & !bInsuffRep & levene){
+    if(!is.na(p.value) && ((bOneWay | bTwoWay) & !bInsuffRep & levene)){
         ypos = ylims[2]-diff(ylims)*0.02
         xpos = xlims[1]+diff(xlims)*0.02
         text(xpos,ypos,paste("Levene Test P-value: ",round(p.value,4))
